.. Pysphalt documentation master file, created by
   sphinx-quickstart on Thu Nov 30 11:03:07 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Pysphalt's documentation!
===========================================

.. toctree::
   :maxdepth: 1
   :caption: Python API:

   api/models

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
